@@ -78,10 +78,10 @@ struct options {
 
 int main(int argc, char *argv[]) { 
   char cmd[512], fstring[16], status = 0, *optstr = "ftsmhbcra:u"; 
-  int curopt;
+  int curopt, curarg;
   unsigned char sec; 
   float curfilelength, totlength = 0; 
-  unsigned int min, curarg; 
+  unsigned int min;
   FILE *file; 
   struct options opts; 
 
@@ -211,7 +211,7 @@ int main(int argc, char *argv[]) {
       eci_command(cmd); 
       eci_command("cs-connect"); 
       if (strlen(eci_last_error()) == 0) {
-        sprintf(cmd, "ai-select %s", argv[curarg]); 
+        sprintf(cmd, "ai-select \"%s\"", argv[curarg]);
         eci_command(cmd); 
         eci_command("ai-get-length"); 
         curfilelength = eci_last_float(); 
