@@ -144,7 +144,6 @@ string EFFECT_VOLUME_BUCKETS::status(void) const
   }
 
   for(unsigned int j = neg_samples_db.size(); j > 0; j--) {
-    DBC_CHECK(j >= 0);
     status_str += std::string("\nNeg ")
       + priv_align_right(bucket_table[j-1].name, 4, ' ')
       + "dB: ";
@@ -330,7 +329,7 @@ std::string EFFECT_VOLUME_PEAK::parameter_names(void) const
   string params;
   for(int n = 0; n < channels(); n++) {
     params += "peak-amplitude-ch" + kvu_numtostr(n + 1);
-    if (n != channels()) params += ",";
+    if (n + 1 < channels()) params += ",";
   }
   return params;
 }
